@@ -17,9 +17,10 @@ use constant TRACE => 5;
 
 my %LEVELS = ( 0 => 'FATAL', 1 => 'ERROR', 2 => 'WARN', 3 => 'INFO', 4 => 'DEBUG', 5 => 'TRACE' );
 
-use constant DEFAULT_LEVEL => 5;
-use constant DEFAULT_SORT_KEYS => 1;
+use constant DEFAULT_LEVEL      => 5;
+use constant DEFAULT_SORT_KEYS  => 1;
 use constant DEFAULT_QUOTE_KEYS => 0;
+use constant DEFAULT_DEEP_COPY  => 1;
 
 use constant DEFAULT_BASE_DIR => '/tmp';
 use constant MAX_FRAME => 10;
@@ -36,7 +37,7 @@ Version 0.20
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 $VERSION = eval $VERSION;
 
@@ -103,6 +104,7 @@ Creates a new logger object.
      dump_depth         => 2,
      sort_keys          => 1,
      quote_keys         => 0,
+     deep_copy          => 1,
      filename_datestamp => 1,
  );
 
@@ -150,6 +152,7 @@ sub new
          dump_depth     => $args{ dump_depth } || 0,
          sort_keys      => exists $args{ sort_keys }  ? $args{ sort_keys }  : DEFAULT_SORT_KEYS,
          quote_keys     => exists $args{ quote_keys } ? $args{ quote_keys } : DEFAULT_QUOTE_KEYS,
+         deep_copy      => exists $args{ deep_copy } ? $args{ deep_copy } : DEFAULT_DEEP_COPY,
          filename       => $args{ filename },
          autoflush      => exists $args{ autoflush } ? $args{ autoflush } : 1,
         _fh             => undef,
@@ -283,6 +286,22 @@ sub quote_keys
     return $self->{ quote_keys };
 }
 
+=head3 deep_copy
+
+Sets C<$Data::Dumper::Deepcopy>.
+
+ $log->deep_copy( 0 );
+
+=cut
+
+sub deep_copy
+{
+    my ( $self, $arg ) = @_;
+    $self->{ deep_copy } = $arg if defined $arg;
+    return $self->{ deep_copy };
+}
+
+
 
 =head3 filename
 
@@ -355,6 +374,8 @@ sub msg
 
     local $Data::Dumper::Quotekeys = $self->quote_keys;
     
+    local $Data::Dumper::Deepcopy = $self->deep_copy;
+
     if ( $level !~ /^\d+$/ )
     {
         # bad log level, so push the 'level' to the 'things'
@@ -678,4 +699,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of Log::AutoDump
+1; # End of Log::AutoDump
\ No newline at end of file
